*****
Model
*****

Several data classes in this module.

Schema
=============================

.. autoclass:: sqllineage.core.models.Schema


Table
=============================

.. autoclass:: sqllineage.core.models.Table


SubQuery
=============================

.. autoclass:: sqllineage.core.models.SubQuery


Column
=============================

.. autoclass:: sqllineage.core.models.Column
